@@ -1,7 +1,7 @@
 /*
  * toc_print.c -- print toc file
  *
- * Copyright (C) 2004, 2005, 2006 Svend Sorensen
+ * Copyright (C) 2004, 2005, 2006, 2007, 2013 Svend Sorensen
  * For license terms, see the file COPYING in this distribution.
  */
 
@@ -16,23 +16,24 @@ void toc_print_cdtext (Cdtext *cdtext, FILE *fp, int istrack);
 void toc_print (FILE *fp, Cd *cd)
 {
 	Cdtext *cdtext = cd_get_cdtext(cd);
-	int i; 	/* track */
+	int i;	/* track */
 	Track *track;
 
 	switch(cd_get_mode(cd)) {
 	case MODE_CD_DA:
 		fprintf(fp, "CD_DA\n");
-	       	break;
+		break;
 	case MODE_CD_ROM:
 		fprintf(fp, "CD_ROM\n");
-	       	break;
+		break;
 	case MODE_CD_ROM_XA:
 		fprintf(fp, "CD_ROM_XA\n");
-	       	break;
+		break;
 	}
 
-	if (NULL != cd_get_catalog(cd))
+	if (NULL != cd_get_catalog(cd)) {
 		fprintf(fp, "CATALOG \"%s\"\n", cd_get_catalog(cd));
+	}
 
 	if(0 != cdtext_is_empty(cdtext)) {
 		fprintf(fp, "CD_TEXT {\n");
@@ -59,37 +60,41 @@ void toc_print_track (FILE *fp, Track *track)
 	switch (track_get_mode(track)) {
 	case MODE_AUDIO:
 		fprintf(fp, "AUDIO");
-	       	break;
+		break;
 	case MODE_MODE1:
 		fprintf(fp, "MODE1");
-	       	break;
+		break;
 	case MODE_MODE1_RAW:
 		fprintf(fp, "MODE1_RAW");
-	       	break;
+		break;
 	case MODE_MODE2:
 		fprintf(fp, "MODE2");
-	       	break;
+		break;
 	case MODE_MODE2_FORM1:
 		fprintf(fp, "MODE2_FORM1");
-	       	break;
+		break;
 	case MODE_MODE2_FORM2:
 		fprintf(fp, "MODE2_FORM2");
-	       	break;
+		break;
 	case MODE_MODE2_FORM_MIX:
 		fprintf(fp, "MODE2_FORM_MIX");
-	       	break;
+		break;
 	}
 	fprintf(fp, "\n");
 
-	if (0 != track_is_set_flag(track, FLAG_PRE_EMPHASIS))
+	if (0 != track_is_set_flag(track, FLAG_PRE_EMPHASIS)) {
 		fprintf(fp, "PRE_EMPHASIS\n");
-	if (0 != track_is_set_flag(track, FLAG_COPY_PERMITTED))
+	}
+	if (0 != track_is_set_flag(track, FLAG_COPY_PERMITTED)) {
 		fprintf(fp, "COPY\n");
-	if (0 != track_is_set_flag(track, FLAG_FOUR_CHANNEL))
+	}
+	if (0 != track_is_set_flag(track, FLAG_FOUR_CHANNEL)) {
 		fprintf(fp, "FOUR_CHANNEL_AUDIO\n");
+	}
 
-	if (NULL != track_get_isrc(track))
+	if (NULL != track_get_isrc(track)) {
 		fprintf(fp, "ISRC \"%s\"\n", track_get_isrc(track));
+	}
 
 	if (0 != cdtext_is_empty(cdtext)) {
 		fprintf(fp, "CD_TEXT {\n");
@@ -104,15 +109,17 @@ void toc_print_track (FILE *fp, Track *track)
 		fprintf(fp, "%s", time_frame_to_mmssff(track_get_zero_pre(track)));
 		fprintf(fp, "\n");
 	}
-		
+
 	fprintf(fp, "FILE ");
 	fprintf(fp, "\"%s\" ", track_get_filename(track));
-	if (0 == track_get_start(track))
+	if (0 == track_get_start(track)) {
 		fprintf(fp, "0");
-	else
+	} else {
 		fprintf(fp, "%s", time_frame_to_mmssff(track_get_start(track)));
-	if (0 != track_get_length(track))
+	}
+	if (0 != track_get_length(track)) {
 		fprintf(fp, " %s", time_frame_to_mmssff(track_get_length(track)));
+	}
 	fprintf(fp, "\n");
 
 	if (0 != track_get_zero_post(track)) {
@@ -120,7 +127,7 @@ void toc_print_track (FILE *fp, Track *track)
 		fprintf(fp, "%s", time_frame_to_mmssff(track_get_zero_post(track)));
 		fprintf(fp, "\n");
 	}
-		
+
 	if (track_get_index(track, 1) != 0) {
 		fprintf(fp, "START ");
 		fprintf(fp, "%s\n", time_frame_to_mmssff(track_get_index(track, 1)));
