@@ -1,17 +1,23 @@
 /*
  * cueprint.c -- print cd information based on a template
  *
- * Copyright (C) 2004, 2005, 2006 Svend Sorensen
+ * Copyright (C) 2004, 2005, 2006, 2007, 2013 Svend Sorensen
  * For license terms, see the file COPYING in this distribution.
  */
 
-#include <stdio.h>
-#include <stdlib.h>		/* exit() */
-#include <string.h>		/* strcmp() */
-#include <getopt.h>
-#include <ctype.h>		/* isdigit() */
+#include <ctype.h>	/* isdigit() */
+#include <getopt.h>	/* getopt_long() */
+#include <stdio.h>	/* fprintf(), printf(), snprintf(), stderr */
+#include <stdlib.h>	/* exit() */
+#include <string.h>	/* strcasecmp() */
 #include "cuefile.h"
 
+#if HAVE_CONFIG_H
+#include "config.h"
+#else /* not HAVE_CONFIG_H */
+#define PACKAGE_STRING "cueprint"
+#endif /* HAVE_CONFIG_H */
+
 /* default templates */
 
 #define D_TEMPLATE "\
@@ -45,7 +51,7 @@ ISRC (CD-TEXT):	%u\n\
 #define VALUE_UNSET ""
 
 /*
- * *_get_* functions can return an int or char *
+ * *_get_* functions can return an int or a char *
  */
 typedef union {
 	int ival;
@@ -55,55 +61,45 @@ typedef union {
 
 char *progname;
 
-void usage (int status)
+/* Print usage information and exit */
+void usage(int status)
 {
 	if (0 == status) {
-		fprintf(stdout, "%s: usage: cueprint [option...] [file...]\n", progname);
-		fputs("\
-\n\
-OPTIONS\n\
--h, --help 			print usage\n\
--i, --input-format cue|toc	set format of file(s)\n\
--n, --track-number <number>	only print track information for single track\n\
--d, --disc-template <template>	set disc template (see TEMPLATE EXPANSION)\n\
--t, --track-template <template>	set track template (see TEMPLATE EXPANSION)\n\
-\n\
-Template Expansion\n\
-Disc:\n\
-%A - album arranger\n\
-%C - album composer\n\
-%G - album genre\n\
-%M - album message\n\
-%N - number of tracks\n\
-%P - album performer\n\
-%S - album songwriter\n\
-%T - album title\n\
-%U - album UPC/EAN\n\
-Track:\n\
-%a - track arranger\n\
-%c - track composer\n\
-%g - track genre\n\
-%i - track ISRC\n\
-%m - track message\n\
-%n - track number\n\
-%p - track perfomer\n\
-%t - track title\n\
-%u - track ISRC (CD-TEXT)\n\
-\n\
-Any other %<character> is expanded to that character.  For example, to get a\n\
-'%', use %%.\n\
-\n\
-", stdout);
-		fprintf(stdout, "default disc template is:\n%s\n", D_TEMPLATE);
-		fprintf(stdout, "default track template is:\n%s\n", T_TEMPLATE);
+		printf("Usage: %s [option...] [file...]\n", progname);
+		printf("Report disc and track information from a CUE or TOC file.\n"
+		       "\n"
+		       "OPTIONS\n"
+		       "-h, --help			print usage\n"
+		       "-i, --input-format cue|toc	set format of file(s)\n"
+		       "-n, --track-number <number>	only print track information for single track\n"
+		       "-d, --disc-template <template>	set disc template\n"
+		       "-t, --track-template <template>	set track template\n"
+		       "-V, --version			print version information\n"
+		       "\n"
+		       "Default disc template: %s\n"
+		       "Default track template: %s\n"
+		       "See the manual page for more information.\n",
+		       D_TEMPLATE, T_TEMPLATE);
 	} else {
-		fprintf(stderr, "run `%s --help' for usage\n", progname);
+		fprintf(stderr, "Try `%s --help' for more information.\n", progname);
 	}
 
 	exit (status);
 }
 
-void disc_field (char *conv, int length, Cd *cd, Value *value)
+/* Print version information and exit */
+void version()
+{
+	printf("%s\n", PACKAGE_STRING);
+
+	exit(0);
+}
+
+/*
+ * TODO: Shouldn't we be using vprintf() to help us out with this stuff?
+ * (Branden Robinson)
+ */
+void disc_field(char *conv, int length, Cd *cd, Value *value)
 {
 	char *c;	/* pointer to conversion character */
 
@@ -113,7 +109,7 @@ void disc_field (char *conv, int length, Cd *cd, Value *value)
 	c = conv + length - 1;
 
 	/*
-	 * after setting value, set *c to specify value type
+	 * After setting value, set *c to specify value type:
 	 * 'd' integer
 	 * 's' string
 	 * 'c' character
@@ -166,7 +162,7 @@ void disc_field (char *conv, int length, Cd *cd, Value *value)
 	}
 }
 
-void track_field (char *conv, int length, Cd *cd, int trackno, Value *value)
+void track_field(char *conv, int length, Cd *cd, int trackno, Value *value)
 {
 	char *c;	/* pointer to conversion character */
 
@@ -230,25 +226,27 @@ void track_field (char *conv, int length, Cd *cd, int trackno, Value *value)
 
 }
 
-/* print a % conversion specification
- * %[flag(s)][width][.precision]<conversion-char>
+/*
+ * Print a conversion specification.
+ * [flag(s)][width][.precision]<conversion-char>
  */
-void print_conv (char *start, int length, Cd *cd, int trackno)
+void print_conv(char *start, int length, Cd *cd, int trackno)
 {
 	char *conv;	/* copy of conversion specification */
 	Value value;
 	char *c;	/* pointer to conversion-char */
 
 	/* TODO: use strndup? */
-	conv = malloc ((unsigned) (length + 1));
+	conv = malloc((unsigned) (length + 1));
 	strncpy(conv, start, length);
 	conv[length] = '\0';
 
 	/* conversion character */
-	if (0 == trackno)
+	if (0 == trackno) {
 		disc_field(conv, length, cd, &value);
-	else
+	} else {
 		track_field(conv, length, cd, trackno, &value);
+	}
 
 	c = conv + length - 1;
 
@@ -266,14 +264,14 @@ void print_conv (char *start, int length, Cd *cd, int trackno)
 			printf(conv, value.sval);
 		break;
 	default:
-		printf("%d: ", strlen(conv));
+		printf("%zu: ", strlen(conv));
 		printf("%s", conv);
 	}
 
 	free(conv);
 }
 
-void cd_printf (char *format, Cd *cd, int trackno)
+void cd_printf(char *format, Cd *cd, int trackno)
 {
 	char *c;	/* pointer into format */
 	char *conv_start;
@@ -303,7 +301,7 @@ void cd_printf (char *format, Cd *cd, int trackno)
 				conv_length++;
 				c++;
 			}
-			
+
 			/* precision */
 			/* '*' not recognized */
 			if ('.' == *c) {
@@ -329,13 +327,14 @@ void cd_printf (char *format, Cd *cd, int trackno)
 	}
 }
 
-int info (char *name, int format, int trackno, char *d_template, char *t_template)
+int info(char *name, int format, int trackno, char *d_template, char *t_template)
 {
 	Cd *cd = NULL;
 	int ntrack;
 
 	if (NULL == (cd = cf_parse(name, &format))) {
-		fprintf(stderr, "%s: input file error\n", name);
+		fprintf(stderr, "%s: error: unable to parse input file"
+		        " `%s'\n", progname, name);
 		return -1;
 	}
 
@@ -352,15 +351,16 @@ int info (char *name, int format, int trackno, char *d_template, char *t_templat
 	} else if (0 < trackno && ntrack >= trackno) {
 		cd_printf(t_template, cd, trackno);
 	} else {
-		fprintf(stderr, "%s: track number out of range\n", progname);
+		fprintf(stderr, "%s: error: track number out of range\n", progname);
 		return -1;
 	}
 
 	return 0;
 }
 
-/* translate escape sequences in a string
- * string is overwritten and terminated
+/* 
+ * Translate escape sequences in a string.
+ * The string is overwritten and terminated.
  * TODO: this does not handle octal and hexidecimal escapes
  *       except for \0
  */
@@ -417,14 +417,18 @@ void translate_escapes(char *s)
 	*write = '\0';
 }
 
-int main (int argc, char **argv)
+int main(int argc, char *argv[])
 {
 	int format = UNKNOWN;
-	int trackno = -1;		/* track number (-1 = unspecified, 0 = disc info) */
+	int trackno = -1;		/* track number (-1 = unspecified,
+					                  0 = disc info) */
 	char *d_template = NULL;	/* disc template */
 	char *t_template = NULL;	/* track template */
+	int ret = 0;			/* return value of info() */
+
+	/* option variables */
+	int c;
 	/* getopt_long() variables */
-	char c;
 	extern char *optarg;
 	extern int optind;
 
@@ -434,12 +438,13 @@ int main (int argc, char **argv)
 		{"track-number", required_argument, NULL, 'n'},
 		{"disc-template", required_argument, NULL, 'd'},
 		{"track-template", required_argument, NULL, 't'},
+		{"version", no_argument, NULL, 'V'},
 		{NULL, 0, NULL, 0}
 	};
 
-	progname = *argv;
+	progname = argv[0];
 
-	while (-1 != (c = getopt_long(argc, argv, "hi:n:d:t:", longopts, NULL))) {
+	while (-1 != (c = getopt_long(argc, argv, "hi:n:d:t:V", longopts, NULL))) {
 		switch (c) {
 		case 'h':
 			usage(0);
@@ -450,7 +455,8 @@ int main (int argc, char **argv)
 			} else if (0 == strcmp("toc", optarg)) {
 				format = TOC;
 			} else {
-				fprintf(stderr, "%s: illegal format `%s'\n", progname, optarg);
+				fprintf(stderr, "%s: error: unknown input file"
+				        " format `%s'\n", progname, optarg);
 				usage(1);
 			}
 			break;
@@ -463,35 +469,48 @@ int main (int argc, char **argv)
 		case 't':
 			t_template = optarg;
 			break;
+		case 'V':
+			version();
+			break;
 		default:
 			usage(1);
 			break;
 		}
 	}
 
-	/* if no disc or track template is set, use the defaults for both */
+	/* If no disc or track template is set, use the defaults for both. */
 	/* TODO: alternative to strdup to get variable strings? */
 	if (NULL == d_template && NULL == t_template) {
 		d_template = strdup(D_TEMPLATE);
 		t_template = strdup(T_TEMPLATE);
 	} else {
-		if (NULL == d_template)
+		if (NULL == d_template) {
 			d_template = strdup("");
+		}
 
-		if (NULL == t_template)
+		if (NULL == t_template) {
 			t_template = strdup("");
+		}
 	}
 
-	/* translate escape sequences */
+	/* Translate escape sequences. */
 	translate_escapes(d_template);
 	translate_escapes(t_template);
 
+	/* What we do depends on the number of operands. */
 	if (optind == argc) {
-		info("-", format, trackno, d_template, t_template);
+		/* No operands: report information about stdin. */
+		ret = info("-", format, trackno, d_template, t_template);
 	} else {
-		for (; optind < argc; optind++)
-			info(argv[optind], format, trackno, d_template, t_template);
+		/* Report information about each operand. */
+		for (; optind < argc; optind++) {
+			ret = info(argv[optind], format, trackno, d_template, t_template);
+			/* Exit if info() returns nonzero. */
+			if (!ret) {
+				break;
+			}
+		}
 	}
 
-	return 0;
+	return ret;
 }
